OC.L10N.register(
    "photos",
    {
    "Public link" : "Enlace público",
    "Photos" : "Fotos",
    "On This Day" : "En este día",
    "Your memories under your control" : "Sus recuerdos bajo su control",
    "All media" : "Todos los medios",
    "Videos" : "Vídeos",
    "Albums" : "Álbumes",
    "Collaborative albums" : "Álbumes colaborativos",
    "People" : "Personas",
    "Folders" : "Carpetas",
    "Favorites" : "Favoritos",
    "On this day" : "En este día",
    "Shared with you" : "Compartido contigo",
    "Tags" : "Etiquetas",
    "Places" : "Ubicaciones",
    "Map" : "Mapa",
    "Photos settings" : "Configuración de fotos",
    "Mark selection as favorite" : "Marcar selección como favorita",
    "Add selection to favorites" : "Añadir selección a favoritos",
    "Remove selection from favorites" : "Eliminar selección de favoritos",
    "Name of the album" : "Nombre del álbum",
    "Location of the album" : "Ubicación del álbum",
    "Back" : "Atrás",
    "Add collaborators" : "Añadir colaboradores",
    "Save" : "Guardar",
    "Create album" : "Crear álbum",
    "Add to Album" : "Añadir al álbum",
    "Add selection to album {albumName}" : "Añadir selección al álbum {albumName}",
    "Shared by" : "Compartido por",
    "Create a new album." : "Crear un álbum nuevo.",
    "Create new album" : "Crear nuevo álbum",
    "New album" : "Nuevo álbum",
    "_%n item_::_%n photos and videos_" : ["%n ítem","%n fotos y videos","%n fotos y videos"],
    "Failed to fetch collaborators list." : "Fallo al recuperar la lista de colaboradores.",
    "Failed to update album." : "Fallo al actualizar el álbum.",
    "Add people or groups who can edit your album" : "Añada personas o grupos que puedan editar su álbum",
    "Search people or groups" : "Buscar personas o grupos",
    "No recommendations. Start typing." : "Sin recomendaciones. Empiece a escribir.",
    "Group" : "Grupo",
    "Remove {collaboratorLabel} from the collaborators list" : "Eliminar {colaboratorLabel} de la lista de colaboradores",
    "Copy the public link" : "Copiar el enlace público",
    "Public link copied!" : "¡Se copió el enlace público!",
    "Copy public link" : "Copiar enlace público",
    "Delete the public link" : "Borrar el enlace público",
    "Create public link share" : "Crear un enlace público compartido",
    "Share via public link" : "Compartir a través de enlace público",
    "This collection does not exist" : "Esta colección no existe",
    "An error occurred" : "Ocurrió un error",
    "No picture for this day" : "No hay fotos para este día",
    "Picture taken on this day will show up here." : "Las fotos tomadas este día aparecerán aquí.",
    "More photos from this day" : "Más fotos de este día",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n foto sin asignar","%n fotos sin asignar","%n fotos sin asignar"],
    "Favorite" : "Marcar como favorito",
    "Favorite image, open the full size \"{name}\" image" : "Imagen favorita, abrir la imagen \"{name}\" a tamaño completo",
    "Open the full size \"{name}\" image" : "Abrir la imagen \"{name}\" a tamaño completo",
    "Select image {imageName}" : "Seleccionar imagen {imageName}",
    "Open the \"{name}\" folder" : "Abrir la carpeta \"{name}\"",
    "Back to {folder}" : "Atrás a {folder}",
    "Go back" : "Ir atrás",
    "Share this folder" : "Compartir esta carpeta",
    "Dates" : "Fechas",
    "Jump to specific date in list" : "Saltar a una fecha específica en la lista",
    "Jump to {date}" : "Ir a {date}",
    "Add to {destination}" : "Añadir a {destination}",
    "The destination folder is owned by {owner}" : "La carpeta de destino es de {owner}",
    "There are no photos or videos yet!" : "¡No hay fotos ni videos todavía!",
    "_{years} year ago_::_{years} years ago_" : ["Hace {years} año","Hace {years} años","Hace {years} años"],
    "Enable squared photos view" : "Habilitar vista de fotos cuadradas",
    "Delete source directory" : "Eliminar directorio de origen",
    "Select a source folder for your media" : "Elegir una carpeta fuente para sus medios",
    "All folders" : "Todas las carpetas",
    "Add a Photos source for the timelines" : "Añadir una fuente de fotos para las líneas de tiempo",
    "Add folder" : "Añadir carpeta",
    "Select the default upload location for your media" : "Seleccione una ubicación de subida predeterminada para sus medios",
    "Home" : "Inicio",
    "Choose default Photos upload and Albums location" : "Ubicación por defecto de subida para Fotos y Álbumes",
    "Choose a different folder" : "Elija una carpeta diferente",
    "View" : "Ver",
    "Media folders" : "Carpetas de medios",
    "Choose the folders from where photos and videos are shown." : "Seleccione las carpetas desde donde se mostrarán las fotos y videos.",
    "Upload folder" : "Subir carpeta",
    "Choose the folder where photos and albums are uploaded to." : "Elija la carpeta donde se cargan las fotos y los álbumes.",
    "_%n photo_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
    "Unselect all" : "Deseleccionar todos",
    "Add photos to this album" : "Añadir fotos a este álbum",
    "Manage collaborators for this album" : "Administrar colaboradores para este álbum",
    "Open actions menu" : "Abrir menú de acciones",
    "Edit album details" : "Editar los detalles del álbum",
    "Download all files in album" : "Descargar todos los archivos del álbum",
    "Delete album" : "Eliminar álbum",
    "Download selected files" : "Descargar archivos seleccionados",
    "Remove selection from album" : "Eliminar selección del álbum",
    "This album does not have any photos or videos yet!" : "¡Este álbum no tiene fotos ni videos todavía!",
    "Add photos to {albumName}" : "Añadir fotos a {albumName}",
    "Manage collaborators" : "Administrar colaboradores",
    "Save collaborators for this album." : "Guardar colaboradores para este álbum",
    "Cover photo for album {albumName}" : "Foto de cubierta para el álbum {albumName}",
    "There is no album yet!" : "¡No hay álbum todavía!",
    "This person could not be found" : "Esta persona no pudo ser encontrada",
    "Rename person" : "Renombrar persona",
    "Merge with different person" : "Unir con una persona diferente",
    "Download selected photos" : "Descargar fotos seleccionadas",
    "Remove from favorites" : "Eliminar de favoritos",
    "Remove person" : "Eliminar persona",
    "Name of this person" : "Nombre de esta persona",
    "Save." : "Guardar.",
    "Merge person" : "Unir persona",
    "Move to different person" : "Mover a una persona diferente",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mover foto a una persona diferente","Mover fotos a una persona diferente","Mover fotos a una persona diferente"],
    "_Remove photo from person_::_Remove photos from person_" : ["Eliminar foto de la persona","Eliminar fotos de la persona","Eliminar fotos de la persona"],
    "This might take some time depending on the size of your photo library." : "Esto podría tomar algún tiempo dependiendo del tamaño de su biblioteca de fotos.",
    "Recognized people will show up here" : "Las personas que logren ser reconocidas se mostrarán aquí",
    "This folder does not exist" : "Esta carpeta no existe",
    "Loading folders …" : "Cargando carpetas …",
    "No photos in here" : "No hay fotos aquí",
    "Taken on {date} at {time}" : "Tomada el {date} a las {time}",
    "This place does not have any photos or videos yet!" : "¡Este lugar no tiene fotos ni videos todavía!",
    "Add photos to this place" : "Añadir fotos a este lugar",
    "Cover photo for place {placeName}" : "Foto de cubierta para el lugar {placeName}",
    "There is no place yet!" : "¡Todavía no hay lugar!",
    "Back to tags overview" : "Regresar a la vista general de etiquetas",
    "No photos with this tag yet" : "No hay fotos con esta etiqueta todavía",
    "No tags yet" : "Todavía no hay etiquetas",
    "Photos with tags will show up here" : "Las fotos con etiquetas aparecerán aquí",
    "Popular tags" : "Etiquetas populares",
    "All tags" : "Todas las etiquetas",
    "One of the source folders does not exist" : "Una de las carpetas fuente no existe",
    "Add to album" : "Añadir al álbum",
    "Delete selection" : "Borrar la selección",
    "No photos or videos in here" : "No hay fotos ni videos aquí",
    "Unassigned faces" : "Caras sin asignar",
    "_%n photos_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
    "Failed to fetch collection." : "Fallo al recuperar la colección.",
    "Failed to fetch collections list." : "Fallo al recuperar la lista de colecciones.",
    "Failed to fetch faces list." : "Fallo al recuperar la lista de caras.",
    "All your media" : "Todos sus medios",
    "Album {title}" : "Álbum {title}",
    "Shared Albums" : "Álbumes compartidos",
    "Shared album {title}" : "Álbum compartido {title}",
    "Public album {title}" : "Álbum público {title}",
    "Tagged photos" : "Fotos etiquetadas",
    "Tagged photo {title}" : "Foto etiquetada {title}",
    "{title}'s face" : "Rostro de {title}",
    "{startDate} to {endDate}" : "{startDate} a {endDate}",
    "Details" : "Detalles",
    "Could not load photos folder" : "No se pudo cargar la carpeta de fotos",
    "One of the source folders does not exists" : "Una de las carpetas fuente no existe",
    "Add" : "Añadir"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
